==> shinken-enterprise_V02.08.01.01_ALL-LANG_Windows-poller-only_FULL_2022-11-17.tar.gz: shinken-enterprise_V02.08.01.01_ALL-LANG_Windows-poller-only_FULL_2022-11-17/shinkensolutions/common_ui/htdocs/js/shinken/translation/translate.js <==
//priority 10
//__lib__ lib_common
var __lang_obj        = {};
var DICTIONARY_COMMON = "common";
var DICTIONARY_COMMON_UI = "common_ui";

var __dictionary_active_name__ = __dictionary_active_name__ || "lang_";

function __gup ( name, url ) {
    if ( !url ) {
        url = location.href;
    }
    name        = name.replace( /[\[]/, "\\\[" ).replace( /[\]]/, "\\\]" );
    var regexS  = "[\\?&]" + name + "=([^&#]*)";
    var regex   = new RegExp( regexS );
    var results = regex.exec( url );
    return results == null ? null : results[ 1 ];
}

function _load_lang_obj_array ( dictionary_origin_array ) {
    for ( var i = 0, _size_i = dictionary_origin_array.length; i < _size_i; i++ ) {
        _load_lang_obj( dictionary_origin_array[ i ] );
    }
}

function _load_lang_obj ( dictionary_origin ) {
    if ( __lang_obj[ dictionary_origin ] ) {
        return;
    }
    var lang                        = __gup( 'lang' );
    lang                            = !lang ? __shinken_lang__ : lang;
    var _to_return                  = dictionary_origin !== DICTIONARY_COMMON ? __dictionary_active_name__ + dictionary_origin + '_' : __dictionary_active_name__;
    if ( dictionary_origin === DICTIONARY_COMMON_UI ){
        _to_return = DICTIONARY_COMMON_UI + "_";
    }
    _to_return += lang === 'fr' ? lang : 'en';
    __lang_obj[ dictionary_origin ] = eval( _to_return );
}

function _ ( to_trad, dictionary_origin ) {
    var elts                    = to_trad.split( '.' );
    var dictionary_origin_array = !dictionary_origin ? [ DICTIONARY_COMMON ] : dictionary_origin;
    _load_lang_obj_array( dictionary_origin_array );
    
    for ( var j = 0, _size_j = dictionary_origin_array.length; j < _size_j; j++ ) {
        var _to_return = __lang_obj[ dictionary_origin_array[ j ] ][ elts[ 0 ] ];
        var _found     = true;
        for ( var i = 0, _size = elts.length; i < _size; i++ ) {
            _to_return = i !== 0 ? _to_return[ elts[ i ] ] : _to_return;
            if ( typeof _to_return === 'undefined' ) {
                _found = false;
                break;
            }
        }
        if ( _found ) {
            return _to_return;
        }
    }
    return 'TO_TRAD(' + to_trad + ')';
}

==> shinken-enterprise_V02.08.01.07_ALL-LANG_Windows-poller-only_FULL_2023-10-03.tar.gz: shinken-enterprise_V02.08.01.07_ALL-LANG_Windows-poller-only_FULL_2023-10-03/shinkensolutions/common_ui/htdocs/js/shinken/translation/translate.js <==
//priority 10
//__lib__ lib_common
var __lang_obj        = {};
var DICTIONARY_COMMON = "common";
var DICTIONARY_COMMON_UI = "common_ui";

var __dictionary_active_name__ = __dictionary_active_name__ || "lang_";

function __gup ( name, url ) {
    if ( !url ) {
        url = location.href;
    }
    name        = name.replace( /[\[]/, "\\\[" ).replace( /[\]]/, "\\\]" );
    var regexS  = "[\\?&]" + name + "=([^&#]*)";
    var regex   = new RegExp( regexS );
    var results = regex.exec( url );
    return results == null ? null : results[ 1 ];
}

function _load_lang_obj_array ( dictionary_origin_array ) {
    for ( var i = 0, _size_i = dictionary_origin_array.length; i < _size_i; i++ ) {
        _load_lang_obj( dictionary_origin_array[ i ] );
    }
}

function _load_lang_obj ( dictionary_origin ) {
    if ( __lang_obj[ dictionary_origin ] ) {
        return;
    }
    var lang                        = __gup( 'lang' );
    lang                            = !lang ? __shinken_lang__ : lang;
    var _to_return                  = dictionary_origin !== DICTIONARY_COMMON ? __dictionary_active_name__ + dictionary_origin + '_' : __dictionary_active_name__;
    if ( dictionary_origin === DICTIONARY_COMMON_UI ){
        _to_return = DICTIONARY_COMMON_UI + "_";
    }
    _to_return += lang === 'fr' ? lang : 'en';
    __lang_obj[ dictionary_origin ] = eval( _to_return );
}
function _load_extra_lang_obj ( dictionary_origin ) {
    if ( __lang_obj[ dictionary_origin ] ) {
        return;
    }
    var lang                        = __gup( 'lang' );
    lang                            = !lang ? __shinken_lang__ : lang;
    var _to_return                  = dictionary_origin + "_";
    _to_return += lang === 'fr' ? lang : 'en';
    __lang_obj[ dictionary_origin ] = eval( _to_return );
}

function _ ( to_trad, dictionary_origin ) {
    var elts                    = to_trad.split( '.' );
    var dictionary_origin_array = !dictionary_origin ? [ DICTIONARY_COMMON ] : dictionary_origin;
    _load_lang_obj_array( dictionary_origin_array );
    
    for ( var j = 0, _size_j = dictionary_origin_array.length; j < _size_j; j++ ) {
        var _to_return = __lang_obj[ dictionary_origin_array[ j ] ][ elts[ 0 ] ];
        var _found     = true;
        for ( var i = 0, _size = elts.length; i < _size; i++ ) {
            _to_return = i !== 0 ? _to_return[ elts[ i ] ] : _to_return;
            if ( typeof _to_return === 'undefined' ) {
                _found = false;
                break;
            }
        }
        if ( _found ) {
            return _to_return;
        }
    }
    return 'TO_TRAD(' + to_trad + ')';
}
